/// <reference types="node" />
import { EventEmitter } from "events";
import type StrictEmitter from "strict-event-emitter-types";
export declare class PromiseQueue extends EventEmitter implements StrictEmitter<EventEmitter, {
    error: (error: Error) => void;
}> {
    #private;
    /** The number of tasks that will be executed concurrently.
     * Note that if concurrency > 1, the queue cannot guarantee FIFO since the tasks' execution times may vary. */
    readonly concurrency: number;
    constructor(
    /** The number of tasks that will be executed concurrently.
     * Note that if concurrency > 1, the queue cannot guarantee FIFO since the tasks' execution times may vary. */
    concurrency?: number);
    /** Pause queue execution */
    pause(): void;
    /** Resume queue execution */
    resume(): void;
    /** Whether the task processing is currently paused. */
    isPaused(): boolean;
    /** Returns the number of uncompleted tasks on the queue. */
    getSize(): number;
    /** Add a prioritized task to the queue.
     * Note that a lower priority number means that the task will be prioritized.
     * Ie.: `0` is the highest priority value.
     */
    addTask<T>(priority: number, task: () => Promise<T>): Promise<T>;
}
